
function demo_intersection

% Demo testing cubature over the intersection of disks.

example=2;
deg=5;

% define domain
[centers,rs]=define_domain(example);

% full set
tic;
xyw = gqintdisk(centers,rs,deg);
cpus(1)=toc;

% compressed set
tic;
[pts,w,momerr] = comprexcub(deg,xyw(:,1:2),xyw(:,3));
cpus(2)=toc;

% stats:
fprintf('\n \n \t Example  : %2.0f',example);
fprintf('\n \t Disks    : %8.0f',length(rs));
fprintf('\n \t Degree   : %8.0f',deg);
fprintf('\n \t #full    : %8.0f',size(xyw,1));
fprintf('\n \t #comp    : %8.0f',size(pts,1));
fprintf('\n \t momerr   : %1.1e',momerr);
fprintf('\n \t cpu full : %1.1e',cpus(1));
fprintf('\n \t cpu comp : %1.1e \n \n',cpus(2));
% plot
figure(1); plot_disks(centers,rs,xyw,pts);














function [centers,rs]=define_domain(example)

switch example
    case 1
      number_disks=10;
      theta=linspace(0,2*pi,number_disks+1);
      theta=theta(1:end-1);
      centers=[cos(theta') sin(theta')];
      rs=1.8*ones(number_disks,1);
    case 2
      number_disks=1000;
      centers=rand(number_disks,2);
      rs=0.8+rand(number_disks,1);
end






function plot_disks(centers,rs,xyw,pts)

clf;

gray_dark=[150,150,150]/256; 
gray_mid=[220,220,220]/256;
disk_color=gray_mid;
circle_color=gray_dark;
circles_size=0.35;

% for k=1:length(rs)
%     center=centers(k,:);
%     r=rs(k);
%     theta=linspace(0,2*pi,1000);
%     rr=linspace(0,r,200);
%     [TH,R]=meshgrid(theta,rr);
%     TH=TH(:); R=R(:);
%     X=center(1)+R.*cos(TH); Y=center(2)+R.*sin(TH);
%     plot(X,Y,'o','MarkerEdgeColor',disk_color,...
%                        'MarkerFaceColor',disk_color,...
%                        'MarkerSize',2)
%     hold on;
% end

center1=centers(1,:);
r1=rs(1);
theta=linspace(0,2*pi,500);
rr=linspace(0,r1,500);
[TH,R]=meshgrid(theta,rr);
TH=TH(:); R=R(:);
X=center1(1)+R.*cos(TH); Y=center1(2)+R.*sin(TH);
in=ones(size(X));
for k=2:length(rs)
    center=centers(k,:); r=rs(k);
    inL=(X-center(1)).^2+(Y-center(2)).^2 <= r^2;
    in=[in inL];
end
in=floor(sum(in,2)/size(in,2));
index_in=find(in == 1);
Xin=X(index_in); Yin=Y(index_in);
plot(Xin,Yin,'o','MarkerEdgeColor',disk_color,...
                 'MarkerFaceColor',disk_color,...
                  'MarkerSize',4)

hold on;

for k=1:length(rs)
    center=centers(k,:);
    r=rs(k);
    theta=linspace(0,2*pi,100);
    TH=TH(:); R=R(:);
    X=center(1)+r*cos(TH); Y=center(2)+r*sin(TH);
    plot(X,Y,'-','MarkerEdgeColor',circle_color,...
                       'MarkerFaceColor',circle_color,...
                       'MarkerSize',circles_size)
    hold on;
end

if isempty(xyw) == 0
    plot(xyw(:,1),xyw(:,2),'b.',...
        'MarkerEdgeColor','b','MarkerFaceColor','b',...
        'MarkerSize',2);
end

if isempty(pts) == 0
    plot(pts(:,1),pts(:,2),'ro',...
        'MarkerEdgeColor','r','MarkerFaceColor','r',...
        'MarkerSize',4);
end

axis off;
axis equal;